# Prover9 Exercises

This is a set of formative exercises designed to teach you the skills of encoding problems into first-order logic representation and solving them using an automated theorem prover. Your solutions can be checked automatically using Dr Brandon Bennett's Autograder, which is built on the classic Prover9 theorem prover embeded within a Gradescope autograder.

1. The Stolen Diamond (10 marks)
2. The Lost Key (10 marks)
3. Rembrandt's Picture (8 marks)
4. Sunday is a Holiday (12 marks)
5. Tarquin's Wisdom (12 marks)
6. A Famous Syllogism (6 marks)
7. Furry Reptiles (6 marks)
8. Homework is Fun (6 marks)
9. Web sites (6 marks)
10. Greedy Rabbits (6 marks)
11. Young Rabbits (8 marks)
12. Parts and Overlaps (10 marks)
13. Honey Crumpets (36 marks)

    Total marks available: 136